package cn.com.infosec.jce.provider.symmetric;

import cn.com.infosec.crypto.CipherKeyGenerator;
import cn.com.infosec.crypto.engines.CamelliaEngine;
import cn.com.infosec.crypto.engines.CamelliaWrapEngine;
import cn.com.infosec.crypto.engines.RFC3211WrapEngine;
import cn.com.infosec.crypto.modes.CBCBlockCipher;
import cn.com.infosec.jce.provider.JCEBlockCipher;
import cn.com.infosec.jce.provider.JCEKeyGenerator;
import cn.com.infosec.jce.provider.JDKAlgorithmParameterGenerator;
import cn.com.infosec.jce.provider.JDKAlgorithmParameters;
import cn.com.infosec.jce.provider.WrapCipherSpi;
import java.security.AlgorithmParameters;
import java.security.InvalidAlgorithmParameterException;
import java.security.SecureRandom;
import java.security.spec.AlgorithmParameterSpec;
import javax.crypto.spec.IvParameterSpec;

public final class Camellia {
   private Camellia() {
   }

   public static class AlgParamGen extends JDKAlgorithmParameterGenerator {
      protected void engineInit(AlgorithmParameterSpec genParamSpec, SecureRandom random) {
         throw new InvalidAlgorithmParameterException("No supported AlgorithmParameterSpec for AES parameter generation.");
      }

      protected AlgorithmParameters engineGenerateParameters() {
         byte[] var1 = new byte[16];
         if (super.random == null) {
            SecureRandom var2;
            var2 = new SecureRandom.<init>();
            super.random = var2;
         }

         super.random.nextBytes(var1);

         try {
            AlgorithmParameters var10000 = AlgorithmParameters.getInstance("Camellia", "INFOSEC");
            var10000.init(new IvParameterSpec(var1));
            return var10000;
         } catch (Exception var3) {
            throw new RuntimeException(var3.getMessage());
         }
      }
   }

   public static class AlgParams extends JDKAlgorithmParameters.IVAlgorithmParameters {
      protected String engineToString() {
         return "Camellia IV";
      }
   }

   public static class CBC extends JCEBlockCipher {
      public CBC() {
         CBC var10000 = this;
         CBCBlockCipher var2;
         CBCBlockCipher var10001 = var2 = new CBCBlockCipher;
         CamelliaEngine var1;
         var1 = new CamelliaEngine.<init>();
         var10001.<init>(var1);
         var10000.<init>(var2, 128);
      }
   }

   public static class ECB extends JCEBlockCipher {
      public ECB() {
         ECB var10000 = this;
         CamelliaEngine var1;
         var1 = new CamelliaEngine.<init>();
         var10000.<init>(var1);
      }
   }

   public static class KeyGen extends JCEKeyGenerator {
      public KeyGen() {
         this(256);
      }

      public KeyGen(int keySize) {
         KeyGen var10000 = this;
         CipherKeyGenerator var2;
         var2 = new CipherKeyGenerator.<init>();
         var10000.<init>("Camellia", keySize, var2);
      }
   }

   public static class KeyGen128 extends KeyGen {
      public KeyGen128() {
         super(128);
      }
   }

   public static class KeyGen192 extends KeyGen {
      public KeyGen192() {
         super(192);
      }
   }

   public static class KeyGen256 extends KeyGen {
      public KeyGen256() {
         super(256);
      }
   }

   public static class RFC3211Wrap extends WrapCipherSpi {
      public RFC3211Wrap() {
         RFC3211Wrap var10000 = this;
         RFC3211WrapEngine var2;
         RFC3211WrapEngine var10001 = var2 = new RFC3211WrapEngine;
         CamelliaEngine var1;
         var1 = new CamelliaEngine.<init>();
         var10001.<init>(var1);
         var10000.<init>(var2, 16);
      }
   }

   public static class Wrap extends WrapCipherSpi {
      public Wrap() {
         Wrap var10000 = this;
         CamelliaWrapEngine var1;
         var1 = new CamelliaWrapEngine.<init>();
         var10000.<init>(var1);
      }
   }
}
